/*
 *  Pedometer - Android App
 *  Copyright (C) 2009 Levente Bagi
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package name.bagi.levente.pedometer;

import java.util.ArrayList;

import sparta.checkers.quals.Sink;
import sparta.checkers.quals.Source;
import static sparta.checkers.quals.FlowPermission.*;

/**
 * Counts steps provided by StepDetector and passes the current
 * step count to the activity.
 */
public class StepDisplayer implements StepListener, SpeakingTimer.Listener {

    private @Source({LITERAL, SHARED_PREFERENCES}) int mCount = 0;
    @Source({LITERAL, SHARED_PREFERENCES}) PedometerSettings mSettings;
    @Source({LITERAL, SHARED_PREFERENCES}) Utils mUtils;

    public StepDisplayer(@Sink({CONDITIONAL, DISPLAY, WRITE_LOGS, SPEAKER, SHARED_PREFERENCES, INTENT, VIBRATE}) PedometerSettings settings, 
                         @Sink({CONDITIONAL, DISPLAY, WRITE_LOGS, SPEAKER, SHARED_PREFERENCES, INTENT, VIBRATE})Utils utils) {
        mUtils = utils;
        mSettings = settings;
        notifyListener();
    }
    public void setUtils(@Sink({CONDITIONAL, DISPLAY, WRITE_LOGS, SPEAKER, SHARED_PREFERENCES, INTENT, VIBRATE}) Utils utils) {
        mUtils = utils;
    }

    public void setSteps(@Sink({CONDITIONAL, DISPLAY, WRITE_LOGS, SPEAKER, SHARED_PREFERENCES, INTENT, VIBRATE}) int steps) {
        mCount = steps;
        notifyListener();
    }
    public void onStep() {
        mCount ++;
        notifyListener();
    }
    public void reloadSettings() {
        notifyListener();
    }
    public void passValue() {
    }
    
    

    //-----------------------------------------------------
    // Listener
    
    public interface Listener {
        public void stepsChanged(@Sink({CONDITIONAL, DISPLAY, WRITE_LOGS, SPEAKER, SHARED_PREFERENCES, INTENT, VIBRATE})int value);
        public void passValue();
    }
    private ArrayList</*@Sink(CONDITIONAL)*/ Listener> mListeners = new ArrayList</*@Sink(CONDITIONAL)*/ Listener>();

    public void addListener(Listener l) {
        mListeners.add(l); 
    }
    public void notifyListener() {
        for (Listener listener : mListeners) {
            listener.stepsChanged((int)mCount);
        }
    }
    
    //-----------------------------------------------------
    // Speaking
    
    public void speak() {
        if (mSettings.shouldTellSteps()) { 
            if (mCount > 0) {
                mUtils.say("" + mCount + " steps");
            }
        }
    }
    
    
}
